# Community

## Community Channels

This documentation may not cover all features comprehensively. If you have any questions or suggestions regarding AstrBot or this documentation, please feel free to reach out to us through the community channels below.

### Discord

<https://discord.gg/hAVk6tgV36>

### GitHub

Welcome to submit Issues or Pull Requests:

- [AstrBotDevs/AstrBot](https://github.com/AstrBotDevs/AstrBot)

### Tencent QQ Groups

- Group 12: 916228568 (New)
- Group 9: 1076659624 (Full)
- Group 10: 1078079676 (Full)
- Group 11: 704659519 (Full)
- Group 1: 322154837 (Full)
- Group 3: 630166526 (Full)
- Group 4: 1077826412 (Full)
- Group 5: 822130018 (Full)
- Group 6: 753075035 (Full)
- Group 7: 743746109 (Full)
- Group 8: 1030353265 (Full)
- **AstrBot Core Development Group: 975206796** (AstrBot development members are usually active here. Welcome to anyone interested in programming/AI technology~)

## Become an AstrBot Organization Member

We welcome you to join us!
